/* Copyright (C) 2003, 2005 Peter Selinger.
   This file is part of farsiweb. It is free software and it is covered
   by the GNU General Public License. See the file COPYING for details. */

/* This file contains the table of transliteration codes for farsiweb. 
   The columns are:

   Column 1: transliteration code (what the user types, e.g. "aa")
   Column 2: unicode translation (e.g. "&#1575;")
   Column 3: unicode translation at word start (or 0 if equal to column 2)
   Column 4: symbol type, e.g. C_LET = letter, C_SYMB = symbol, C_MOD =
             modifier
   Column 5: symbol's common name

   If column 1 = NULL, the symbol is currently unassigned, i.e., there
   is no transliteration for it.

   You can customize this file to accommodate your own symbols,
   languages, or scripts.
*/

#include <stdio.h>
#include "codetable.h"

static struct trans_s translation_table[] = {
  {"<<",   "",        0,                C_BEGIN,   "begin block"         },
  {">>",   "",        0,                C_END,     "end block"           },
  {"<",    "<",       0,                C_BLIT(1), "begin html tag"      },
  {">",    ">",       0,                C_ELIT(1), "end html tag"        },
  {"[",    "",        0,                C_BLIT(2), "begin literal"       },
  {"]",    "",        0,                C_ELIT(2), "end literal"         },
  {"::",   "",        0,                C_NULL,    "separator"           },
  {"\\",   "",        0,                C_ESC,     "escape"              },
  {"#",    "&#8204;", 0,                C_SYMB,    "zero-width space"    },
  {NULL,   "&#1573;", 0,                C_LET,     "alef_hamze"          },
  {NULL,   "&#1574;", 0,                C_LET,     "ye-hamze"            },
  {NULL,   "&#1577;", 0,                C_LET,     "he-.."               },
  {NULL,   "&#1603;", 0,                C_LET,     "kaaf-var"            },
  {NULL,   "&#1609;", 0,                C_LET,     "ye-var"              },
  {NULL,   "&#1610;", 0,                C_LET,     "ye-var"              },
  {NULL,   "&#1612;", 0,                C_MOD,     "^?"                  },
  {NULL,   "&#1613;", 0,                C_MOD,     "_//"                 },
  {NULL,   "&#1618;", 0,                C_MOD,     "^o"                  },
  {NULL,   "&#1619;", 0,                C_MOD,     "^~"                  },
  {NULL,   "&#1620;", 0,                C_MOD,     "^hamze"              },
  {NULL,   "&#1621;", 0,                C_MOD,     "_hamze"              },
  {NULL,   "&#1632;", 0,                C_SYMB,    "0-var"               },
  {NULL,   "&#1633;", 0,                C_SYMB,    "1-var"               },
  {NULL,   "&#1634;", 0,                C_SYMB,    "2-var"               },
  {NULL,   "&#1635;", 0,                C_SYMB,    "3-var"               },
  {NULL,   "&#1636;", 0,                C_SYMB,    "4-var"               },
  {NULL,   "&#1637;", 0,                C_SYMB,    "5-var"               },
  {NULL,   "&#1638;", 0,                C_SYMB,    "6-var"               },
  {NULL,   "&#1639;", 0,                C_SYMB,    "7-var"               },
  {NULL,   "&#1640;", 0,                C_SYMB,    "8-var"               },
  {NULL,   "&#1641;", 0,                C_SYMB,    "9-var"               },
  {",",    "&#1548;", 0,                C_SYMB,    "comma"               },
  {";",    "&#1563;", 0,                C_SYMB,    "semicolon"           },
  {"?",    "&#1567;", 0,                C_SYMB,    "question mark"       },
  {"%",    "&#1642;", 0,                C_SYMB,    "percent"             },
  {NULL,   "&#1549;", 0,                C_SYMB,    "date separator"      },
  {"/",    "&#1643;", 0,                C_SYMB,    "decimal separator"   },
  {"`",    "&#1644;", 0,                C_SYMB,    "thousands separator" },
  {"*",    "&#1645;", 0,                C_SYMB,    "asterisk"            },
  {"Rial", "&#65020;",0,                C_SYMB,    "rial"                },
  {"0",    "&#1776;", 0,                C_SYMB,    "0"                   },
  {"1",    "&#1777;", 0,                C_SYMB,    "1"                   },
  {"2",    "&#1778;", 0,                C_SYMB,    "2"                   },
  {"3",    "&#1779;", 0,                C_SYMB,    "3"                   },
  {"4",    "&#1780;", 0,                C_SYMB,    "4"                   },
  {"5",    "&#1781;", 0,                C_SYMB,    "5"                   },
  {"6",    "&#1782;", 0,                C_SYMB,    "6"                   },
  {"7",    "&#1783;", 0,                C_SYMB,    "7"                   },
  {"8",    "&#1784;", 0,                C_SYMB,    "8"                   },
  {"9",    "&#1785;", 0,                C_SYMB,    "9"                   },
  {"A",    "&#1575;", "&#1570;",        C_LET,     "alef"                },
  {"aa",   "&#1575;", "&#1570;",        C_LET,     "alef"                },
  {"a",    "",        "&#1575;",        C_LET,     "a"                   },
  {"e",    "",        "&#1575;",        C_LET,     "e"                   },
  {"b",    "&#1576;", 0,                C_LET,     "be"                  },
  {"p",    "&#1662;", 0,                C_LET,     "pe"                  },
  {"t",    "&#1578;", 0,                C_LET,     "te"                  },
  {"S",    "&#1579;", 0,                C_LET,     "se"                  },
  {"j",    "&#1580;", 0,                C_LET,     "jim"                 },
  {"ch",   "&#1670;", 0,                C_LET,     "che"                 },
  {"H",    "&#1581;", 0,                C_LET,     "he"                  },
  {"kh",   "&#1582;", 0,                C_LET,     "khe"                 },
  {"d",    "&#1583;", 0,                C_LET,     "daal"                },
  {"ZZ",   "&#1584;", 0,                C_LET,     "zaal"                },
  {"r",    "&#1585;", 0,                C_LET,     "re"                  },
  {"z",    "&#1586;", 0,                C_LET,     "ze"                  },
  {"zh",   "&#1688;", 0,                C_LET,     "zhe"                 },
  {"s",    "&#1587;", 0,                C_LET,     "sin"                 },
  {"sh",   "&#1588;", 0,                C_LET,     "shin"                },
  {"ss",   "&#1589;", 0,                C_LET,     "saad"                },
  {"c",    "&#1589;", 0,                C_LET,     "saad"                },
  {"zz",   "&#1590;", 0,                C_LET,     "zaad"                },
  {"T",    "&#1591;", 0,                C_LET,     "taa"                 },
  {"Z",    "&#1592;", 0,                C_LET,     "zaa"                 },
  {"\'",   "&#1593;", 0,                C_LET,     "'ein"                },
  {"gh",   "&#1594;", 0,                C_LET,     "ghein"               },
  {"f",    "&#1601;", 0,                C_LET,     "fe"                  },
  {"q",    "&#1602;", 0,                C_LET,     "qaaf"                },
  {"k",    "&#1705;", 0,                C_LET,     "kaaf"                },
  {"g",    "&#1711;", 0,                C_LET,     "gaaf"                },
  {"l",    "&#1604;", 0,                C_LET,     "laam"                },
  {"m",    "&#1605;", 0,                C_LET,     "mim"                 },
  {"n",    "&#1606;", 0,                C_LET,     "nun"                 },
  {"v",    "&#1608;", 0,                C_LET,     "vaav"                },
  {"u",    "&#1608;", "&#1575;&#1608;", C_LET,     "vaav"                },
  {"oo",   "&#1608;", "&#1575;&#1608;", C_LET,     "vaav"                },
  {"O",    "&#1608;", "&#1575;&#1608;", C_LET,     "vaav"                },
  {"o",    "",        "&#1575;",        C_LET,     "o"                   },
  {"h",    "&#1607;", 0,                C_LET,     "he"                  },
  {"y",    "&#1740;", 0,                C_LET,     "ye"                  },
  {"i",    "&#1740;", "&#1575;&#1740;", C_LET,     "ye"                  },
  {"ee",   "&#1740;", "&#1575;&#1740;", C_LET,     "ye"                  },
  {"ei",   "&#1740;", 0,                C_LET,     "ye"                  },
  {"ey",   "&#1740;", 0,                C_LET,     "ye"                  },
  {"_",    "&#1600;", 0,                C_LET,     "extender"            },
  {"M",    "&#1569;", 0,                C_LET,     "hamze"               },
  {"hM",   "&#1728;", 0,                C_LET,     "he-hamze"            },
  {"aM",   "&#1571;", 0,                C_LET,     "alef-hamze"          },
  {"vM",   "&#1572;", 0,                C_LET,     "vaav-hamze"          },
  {"uM",   "&#1572;", 0,                C_LET,     "vaav-hamze"          },
  {"^an",  "&#1611;", 0,                C_MOD,     "tanvin (an)"         },
  {"AN",   "&#1575;&#1611;", 0,         C_LET,     "alef-tanvin (an)"    },
  {"^a",   "&#1614;", 0,                C_MOD,     "fathe (a)"           },
  {"^o",   "&#1615;", 0,                C_MOD,     "zamme (o)"           },
  {"^e",   "&#1616;", 0,                C_MOD,     "kasre (e)"           },
  {"^w",   "&#1617;", 0,                C_MOD,     "tashdid (double)"    },
  {0, 0, 0, 0}
};

struct trans_s *trans = translation_table;
